brucem updated this revision to Diff 35339.
brucem added a comment.

Rename to opaque_compiler_type_t instead.


http://reviews.llvm.org/D13039

Files:
  include/lldb/Expression/ASTDumper.h
  include/lldb/Symbol/ClangASTImporter.h
  include/lldb/lldb-types.h
  source/Commands/CommandObjectMemory.cpp
  source/Expression/ASTDumper.cpp
  source/Expression/ClangASTSource.cpp
  source/Expression/ClangExpressionDeclMap.cpp
  source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.h
  source/Symbol/ClangASTContext.cpp
  source/Symbol/ClangASTImporter.cpp
  source/Symbol/CompilerType.cpp

Index: source/Symbol/CompilerType.cpp
===================================================================
--- source/Symbol/CompilerType.cpp
+++ source/Symbol/CompilerType.cpp
@@ -1255,7 +1255,7 @@
 }
 
 //clang::CXXRecordDecl *
-//CompilerType::GetAsCXXRecordDecl (lldb::clang_type_t opaque_clang_qual_type)
+//CompilerType::GetAsCXXRecordDecl (lldb::opaque_compiler_type_t opaque_clang_qual_type)
 //{
 //    if (opaque_clang_qual_type)
 //        return clang::QualType::getFromOpaquePtr(opaque_clang_qual_type)->getAsCXXRecordDecl();
Index: source/Symbol/ClangASTImporter.cpp
===================================================================
--- source/Symbol/ClangASTImporter.cpp
+++ source/Symbol/ClangASTImporter.cpp
@@ -59,10 +59,10 @@
     return QualType();
 }
 
-lldb::clang_type_t
+lldb::opaque_compiler_type_t
 ClangASTImporter::CopyType (clang::ASTContext *dst_ast,
                             clang::ASTContext *src_ast,
-                            lldb::clang_type_t type)
+                            lldb::opaque_compiler_type_t type)
 {
     return CopyType (dst_ast, src_ast, QualType::getFromOpaquePtr(type)).getAsOpaquePtr();
 }
@@ -237,10 +237,10 @@
     }
 };
 
-lldb::clang_type_t
+lldb::opaque_compiler_type_t
 ClangASTImporter::DeportType (clang::ASTContext *dst_ctx,
                               clang::ASTContext *src_ctx,
-                              lldb::clang_type_t type)
+                              lldb::opaque_compiler_type_t type)
 {
     Log *log(lldb_private::GetLogIfAllCategoriesSet (LIBLLDB_LOG_EXPRESSIONS));
   
@@ -268,7 +268,7 @@
     minion_sp->InitDeportWorkQueues(&decls_to_deport,
                                     &decls_already_deported);
     
-    lldb::clang_type_t result = CopyType(dst_ctx, src_ctx, type);
+    lldb::opaque_compiler_type_t result = CopyType(dst_ctx, src_ctx, type);
     
     minion_sp->ExecuteDeportWorkQueues();
     
Index: source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.h
===================================================================
--- source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.h
+++ source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.h
@@ -323,8 +323,8 @@
 protected:
     typedef llvm::DenseMap<const DWARFDebugInfoEntry *, lldb_private::Type *> DIEToTypePtr;
     typedef llvm::DenseMap<const DWARFDebugInfoEntry *, lldb::VariableSP> DIEToVariableSP;
-    typedef llvm::DenseMap<const DWARFDebugInfoEntry *, lldb::clang_type_t> DIEToClangType;
-    typedef llvm::DenseMap<lldb::clang_type_t, DIERef> ClangTypeToDIE;
+    typedef llvm::DenseMap<const DWARFDebugInfoEntry *, lldb::opaque_compiler_type_t> DIEToClangType;
+    typedef llvm::DenseMap<lldb::opaque_compiler_type_t, DIERef> ClangTypeToDIE;
 
     enum
     {
Index: source/Expression/ClangExpressionDeclMap.cpp
===================================================================
--- source/Expression/ClangExpressionDeclMap.cpp
+++ source/Expression/ClangExpressionDeclMap.cpp
@@ -1614,11 +1614,11 @@
     }
 }
 
-//static clang_type_t
+//static opaque_compiler_type_t
 //MaybePromoteToBlockPointerType
 //(
 //    ASTContext *ast_context,
-//    clang_type_t candidate_type
+//    opaque_compiler_type_t candidate_type
 //)
 //{
 //    if (!candidate_type)
@@ -1946,7 +1946,7 @@
             QualType var_type = var_decl->getType();
             TypeFromParser parser_type(var_type.getAsOpaquePtr(), ClangASTContext::GetASTContext(&var_decl->getASTContext()));
 
-            lldb::clang_type_t copied_type = m_ast_importer->CopyType(scratch_ast_context->getASTContext(), &var_decl->getASTContext(), var_type.getAsOpaquePtr());
+            lldb::opaque_compiler_type_t copied_type = m_ast_importer->CopyType(scratch_ast_context->getASTContext(), &var_decl->getASTContext(), var_type.getAsOpaquePtr());
 
             if (!copied_type)
             {
Index: source/Expression/ClangASTSource.cpp
===================================================================
--- source/Expression/ClangASTSource.cpp
+++ source/Expression/ClangASTSource.cpp
@@ -401,7 +401,7 @@
         return NULL;
 
     TypeFromUser complete_type = TypeFromUser(complete_type_sp->GetFullCompilerType ());
-    lldb::clang_type_t complete_opaque_type = complete_type.GetOpaqueQualType();
+    lldb::opaque_compiler_type_t complete_opaque_type = complete_type.GetOpaqueQualType();
 
     if (!complete_opaque_type)
         return NULL;
Index: source/Expression/ASTDumper.cpp
===================================================================
--- source/Expression/ASTDumper.cpp
+++ source/Expression/ASTDumper.cpp
@@ -75,7 +75,7 @@
     m_dump = type.getAsString();
 }
 
-ASTDumper::ASTDumper (lldb::clang_type_t type)
+ASTDumper::ASTDumper (lldb::opaque_compiler_type_t type)
 {
     m_dump = clang::QualType::getFromOpaquePtr(type).getAsString();
 }
Index: source/Commands/CommandObjectMemory.cpp
===================================================================
--- source/Commands/CommandObjectMemory.cpp
+++ source/Commands/CommandObjectMemory.cpp
@@ -533,7 +533,7 @@
                 clang::TypeDecl *tdecl = target->GetPersistentVariables().GetPersistentType(ConstString(lookup_type_name));
                 if (tdecl)
                 {
-                    clang_ast_type.SetCompilerType(ClangASTContext::GetASTContext(&tdecl->getASTContext()),(const lldb::clang_type_t)tdecl->getTypeForDecl());
+                    clang_ast_type.SetCompilerType(ClangASTContext::GetASTContext(&tdecl->getASTContext()),(const lldb::opaque_compiler_type_t)tdecl->getTypeForDecl());
                 }
             }
             
Index: include/lldb/lldb-types.h
===================================================================
--- include/lldb/lldb-types.h
+++ include/lldb/lldb-types.h
@@ -110,7 +110,7 @@
     typedef uint64_t    offset_t;
     typedef int32_t     break_id_t;
     typedef int32_t     watch_id_t;
-    typedef void *      clang_type_t;
+    typedef void *      opaque_compiler_type_t;
     typedef uint64_t    queue_id_t;
 }
 
Index: include/lldb/Symbol/ClangASTImporter.h
===================================================================
--- include/lldb/Symbol/ClangASTImporter.h
+++ include/lldb/Symbol/ClangASTImporter.h
@@ -96,20 +96,20 @@
               clang::ASTContext *src_ctx,
               clang::QualType type);
     
-    lldb::clang_type_t
+    lldb::opaque_compiler_type_t
     CopyType (clang::ASTContext *dst_ctx,
               clang::ASTContext *src_ctx,
-              lldb::clang_type_t type);
+              lldb::opaque_compiler_type_t type);
     
     clang::Decl *
     CopyDecl (clang::ASTContext *dst_ctx,
               clang::ASTContext *src_ctx,
               clang::Decl *decl);
     
-    lldb::clang_type_t
+    lldb::opaque_compiler_type_t
     DeportType (clang::ASTContext *dst_ctx,
                 clang::ASTContext *src_ctx,
-                lldb::clang_type_t type);
+                lldb::opaque_compiler_type_t type);
     
     clang::Decl *
     DeportDecl (clang::ASTContext *dst_ctx,
Index: include/lldb/Expression/ASTDumper.h
===================================================================
--- include/lldb/Expression/ASTDumper.h
+++ include/lldb/Expression/ASTDumper.h
@@ -26,7 +26,7 @@
     ASTDumper (clang::DeclContext *decl_ctx);
     ASTDumper (const clang::Type *type);
     ASTDumper (clang::QualType type);
-    ASTDumper (lldb::clang_type_t type);
+    ASTDumper (lldb::opaque_compiler_type_t type);
     ASTDumper (const CompilerType &clang_type);
     
     const char *GetCString();
_______________________________________________
lldb-commits mailing list
lldb-commits@lists.llvm.org
http://lists.llvm.org/cgi-bin/mailman/listinfo/lldb-commits

Reply via email to
Index: source/Symbol/ClangASTContext.cpp
===================================================================
--- source/Symbol/ClangASTContext.cpp
+++ source/Symbol/ClangASTContext.cpp
@@ -841,7 +841,7 @@
 {
     if (ast)
     {
-        clang_type_t clang_type = nullptr;
+        opaque_compiler_type_t clang_type = nullptr;
         
         switch (basic_type)
         {
@@ -2124,7 +2124,7 @@
 // so we can support remote targets. The code below also requires a patch to
 // llvm::APInt.
 //bool
 //ClangASTContext::ConvertFloatValueToString (ASTContext *ast, clang_type_t clang_type, const uint8_t* bytes, size_t byte_size, int apint_byte_order, std::string &float_str)
 //{
 //  uint32_t count = 0;
 //  bool is_complex = false;
@@ -5024,7 +5024,7 @@
     return count;
 }
 
-static clang_type_t
+static opaque_compiler_type_t
 GetObjCFieldAtIndex (clang::ASTContext *ast,
                      clang::ObjCInterfaceDecl *class_interface_decl,
                      size_t idx,
@@ -2124,7 +2124,7 @@
 // llvm::APInt.
 //bool
-//ClangASTContext::ConvertFloatValueToString (ASTContext *ast, clang_type_t clang_type, const uint8_t* bytes, size_t byte_size, int apint_byte_order, std::string &float_str)
+//ClangASTContext::ConvertFloatValueToString (ASTContext *ast, opaque_compiler_type_t clang_type, const uint8_t* bytes, size_t byte_size, int apint_byte_order, std::string &float_str)
 //{
 //  uint32_t count = 0;